from typing import Final


class OAPI:

    ApplicationJson: Final[str] = "application/json"

    Components: Final[str] = "components"
    Content: Final[str] = "content"

    Get: Final[str] = "get"

    Paths: Final[str] = "paths"
    Post: Final[str] = "post"

    RequestBody: Final[str] = "requestBody"
    Required: Final[str] = "required"
    Responses: Final[str] = "responses"

    Schema: Final[str] = "schema"


